import color from 'color';
import { black, white } from '../../styles/themes/v2/colors';
import overlay from '../../styles/overlay';
export const getCardCoverStyle = _ref => {
  let {
    theme,
    index,
    total
  } = _ref;
  const {
    isV3,
    roundness
  } = theme;

  if (index === 0) {
    if (total === 1) {
      return {
        borderRadius: roundness
      };
    }

    if (isV3) {
      return {
        borderRadius: roundness
      };
    }

    return {
      borderTopLeftRadius: roundness,
      borderTopRightRadius: roundness
    };
  }

  if (typeof total === 'number' && index === total - 1) {
    return {
      borderBottomLeftRadius: roundness
    };
  }

  return undefined;
};

const getBorderColor = _ref2 => {
  let {
    theme
  } = _ref2;

  if (theme.isV3) {
    return theme.colors.outline;
  }

  if (theme.dark) {
    return color(white).alpha(0.12).rgb().string();
  }

  return color(black).alpha(0.12).rgb().string();
};

const getBackgroundColor = _ref3 => {
  let {
    theme,
    isMode,
    isAdaptiveMode,
    elevation
  } = _ref3;

  if (theme.isV3 && isMode('contained')) {
    return theme.colors.surfaceVariant;
  }

  if (theme.dark && isAdaptiveMode) {
    return overlay(elevation, theme.colors.surface);
  }

  return theme.colors.surface;
};

export const getCardColors = _ref4 => {
  let {
    theme,
    mode,
    isAdaptiveMode,
    elevation
  } = _ref4;

  const isMode = modeToCompare => {
    return mode === modeToCompare;
  };

  return {
    backgroundColor: getBackgroundColor({
      theme,
      isMode,
      isAdaptiveMode,
      elevation
    }),
    borderColor: getBorderColor({
      theme
    })
  };
};
//# sourceMappingURL=helpers.js.map